const path = require('path');

const HtmlWebpackInlineSourcePlugin = require('html-webpack-inline-source-plugin');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const webpack = require('webpack');
const UglifyJsPlugin = require('uglifyjs-webpack-plugin')


const isDevServer = process.argv.some(arg => /webpack-dev-server/.test(arg));
const mode = process.env.NODE_ENV || 'development';


module.exports = (isDevServer ?  [] : [
  {
    entry: {
      index: path.resolve(__dirname, 'src', 'index.js'),
    },
    output: {
      path: path.resolve(__dirname, 'dist'),
      filename: '[name].js',
      library: 'browserprint',
      libraryTarget: 'umd',
      umdNamedDefine: true,
    },
    module: {
      rules: [
        {
          test: /\.js$/,
          include: path.resolve(__dirname, 'src'),
          enforce: 'pre',
          loader: 'eslint-loader',
        },
        {
          test: /\.js$/,
          include: path.resolve(__dirname, 'src'),
          loader: 'babel-loader',
        },
      ],
    },
    plugins: [
      new webpack.DefinePlugin({
        VERSION: JSON.stringify(require('./package.json').version),
      }),
    ],
    target: 'node',
    devtool: 'source-map',
    optimization: {
      minimizer: [
        new UglifyJsPlugin({
          sourceMap: mode === 'development',
          uglifyOptions: {
            mangle: {
              reserved: [
                'browserprint',
              ],
            },
          },
        }),
      ],
    },
    mode,
  }]).concat([{
    entry: {
      'test-page': path.resolve(__dirname, 'src', 'test-page.js'),
    },
    output: {
      path: path.resolve(__dirname, 'dist'),
    },
    module: {
      rules: (isDevServer ? [] : [
        isDevServer ? null : {
          test: /\.js$/,
          include: path.resolve(__dirname, 'src'),
          enforce: 'pre',
          loader: 'eslint-loader',
        },
      ]).concat([
        {
          test: /\.js$/,
          include: path.resolve(__dirname, 'src'),
          loader: 'babel-loader',
        },
      ]),
    },
    plugins: [
      new webpack.DefinePlugin({
        VERSION: JSON.stringify(require('./package.json').version),
      }),
      new HtmlWebpackPlugin({
        inlineSource: 'test-page.js$',
      }),
      new HtmlWebpackInlineSourcePlugin(),
    ],
    target: 'web',
    devtool: 'source-map',
    optimization: {
      minimizer: [
        new UglifyJsPlugin({
          sourceMap: mode === 'development',
          uglifyOptions: {
            mangle: {
              reserved: [
                'browserprint',
              ],
            },
          },
        }),
      ],
    },
    mode,
  },
]);
